@@ -27,3 +27,18 @@ def pull(key, ticker, start, end):
 	data = data.text
 	
 	return json.loads(data)['results']
+
+def remaining_pulls(key):
+	url = CONTACT + '/pulls/'
+	url += '?key={}'.format(key)
+	data = requests.get(url)
+	data = data.text
+	return json.loads(data)['pulls']
+
+
+def coverage(key):
+	url = CONTACT + '/tickers/'
+	url += '?key={}'.format(key)
+	data = requests.get(url)
+	data = data.text
+	return json.loads(data)['coverage']
